"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var chai_1 = require("chai");
var expression_utils_1 = require("../expression-utils");
var _expressionUtils = new expression_utils_1.ExpressionUtils();
var _expressionUtilsCustomSeparador = new expression_utils_1.ExpressionUtils("-");
var ExpressionUsage = /** @class */ (function () {
    function ExpressionUsage() {
    }
    ExpressionUsage.expression = function (expression) {
        return _expressionUtils.getColumnByExpression(expression);
    };
    ExpressionUsage.lambda = function (expression) {
        var result = _expressionUtils.getColumnByLambdaExpression(expression);
        return result;
    };
    return ExpressionUsage;
}());
exports.ExpressionUsage = ExpressionUsage;
describe("Expression method", function () {
    it("should return id", function () {
        var result = ExpressionUsage.expression(function (x) { return x.id; });
        chai_1.expect(result).to.equal("id");
    });
    it("should return description", function () {
        var result = ExpressionUsage.expression(function (x) { return x.description; });
        chai_1.expect(result).to.equal("description");
    });
    it("should return date", function () {
        var result = ExpressionUsage.expression(function (x) { return x.date; });
        chai_1.expect(result).to.equal("date");
    });
    it("should return isValid", function () {
        var result = ExpressionUsage.expression(function (x) { return x.isValid; });
        chai_1.expect(result).to.equal("isValid");
    });
    it("should return reference_name", function () {
        var result = ExpressionUsage.expression(function (x) { return x.reference.name; });
        chai_1.expect(result).to.equal("reference_name");
    });
    it("should return reference_id", function () {
        var result = _expressionUtils.getColumnByExpression(function (x) { return x.reference.id; });
        chai_1.expect(result).to.equal("reference_id");
    });
    it("should return reference-id with custom separator", function () {
        var result = _expressionUtilsCustomSeparador.getColumnByExpression(function (x) { return x.reference.id; });
        chai_1.expect(result).to.equal("reference-id");
    });
});
describe("Expression get value", function () {
    var instance = {
        id: 1,
        name: "Test",
        description: "Descrição",
        date: new Date(),
        isValid: true,
        reference: {
            id: 2,
            name: "Reference"
        }
    };
    it("get description", function () {
        var result = _expressionUtils.getValue(instance, "description");
        chai_1.expect(result).to.equal("Descrição");
    });
    it("get reference.id", function () {
        var result = _expressionUtils.getValue(instance, "reference.id");
        chai_1.expect(result).to.equal(2);
    });
    it("get reference.name", function () {
        var result = _expressionUtils.getValue(instance, "reference.name");
        chai_1.expect(result).to.equal("Reference");
    });
    it("get by expression reference.name", function () {
        var result = _expressionUtils.getValueByExpression(instance, function (x) { return x.reference.name; });
        chai_1.expect(result).to.equal("Reference");
    });
    it("get reference.abc not exist", function () {
        var result = _expressionUtils.getValue(instance, "reference.abc");
        chai_1.expect(result).to.equal(void 0);
    });
});
describe("Lambda Expression method", function () {
    it("should return id == 0", function () {
        var result = ExpressionUsage.lambda(function (x) { return x.id == 0; });
        chai_1.expect(result.columnLeft).to.equal("id");
        chai_1.expect(result.operator).to.equal("==");
        chai_1.expect(result.columnRight).to.equal("0");
    });
    it("should return column with column", function () {
        var result = ExpressionUsage.lambda(function (x) { return x.id >= x.reference.id; });
        chai_1.expect(result.columnLeft).to.equal("id");
        chai_1.expect(result.operator).to.equal(">=");
        chai_1.expect(result.columnRight).to.equal("reference_id");
    });
    it("should value similar column", function () {
        var result1 = ExpressionUsage.lambda(function (x) { return x.name == "x.reference.id"; });
        chai_1.expect(result1.columnLeft).to.equal("name");
        chai_1.expect(result1.operator).to.equal("==");
        chai_1.expect(result1.columnRight).to.equal("\"x.reference.id\"");
        var result2 = ExpressionUsage.lambda(function (x) { return x.name == 'x.reference.id'; });
        chai_1.expect(result2.columnLeft).to.equal("name");
        chai_1.expect(result2.operator).to.equal("==");
        chai_1.expect(result2.columnRight).to.equal("'x.reference.id'");
    });
});
